import sys
from functools import cache

import tumfl

from ._utils import MAIN_PATH


@cache
def verify_script(script: str) -> None:
    """
    Verify the given script for correctness.
    This is a placeholder function and should be implemented with actual verification logic.
    """
    try:
        tumfl.parse(script)
    except tumfl.error.TumflError as e:
        if isinstance(e, tumfl.error.ParserError):
            print(e.full_error)
        else:
            print(e)
        sys.exit(1)


@cache
def resolve_and_verify_script(script_path: str) -> str:
    """
    Resolve dependencies in the given script and verify its correctness.
    """
    try:
        ast = tumfl.resolve_recursive(MAIN_PATH / script_path, [MAIN_PATH])
    except tumfl.error.TumflError as e:
        if isinstance(e, tumfl.error.ParserError):
            print(e.full_error)
        else:
            print(e)
        sys.exit(1)
    return tumfl.format(ast)



import sys
from pathlib import Path

import tumfl
from sw_mc_lib import Position
from sw_mc_lib.Components import (
    PropertyDropdown,
    PropertyNumber,
    PropertySlider,
    PropertyText,
    PropertyToggle,
)

MAIN_PATH: Path = Path(sys.argv[0]).parent.resolve()

# use newline as statement separator, since it is more readable and does not consume more space
tumfl.formatter.MinifiedStyle.STATEMENT_SEPARATOR = "\n"

PROPERTIES = (
    PropertyNumber,
    PropertySlider,
    PropertyText,
    PropertyToggle,
    PropertyDropdown,
)
PROPERTY_IDS: set[str] = {str(cls(0, Position()).type.value) for cls in PROPERTIES}

BUILDER_IDENTIFIER: str = "Built with sw_mc_builder version 1"
